@@ -25,7 +25,7 @@ import multiprocessing
 from io import open
 import re
 
-from glances.compat import ConfigParser, NoOptionError, system_exec
+from glances.compat import ConfigParser, NoOptionError, NoSectionError, system_exec
 from glances.globals import BSD, LINUX, MACOS, SUNOS, WINDOWS
 from glances.logger import logger
 
@@ -107,7 +107,11 @@ class Config(object):
         # Re patern for optimize research of `foo`
         self.re_pattern = re.compile(r'(\`.+?\`)')
 
-        self.parser = ConfigParser()
+        try:
+            self.parser = ConfigParser(interpolation=None)
+        except TypeError:
+            self.parser = ConfigParser()
+
         self.read()
 
     def config_file_paths(self):
@@ -153,6 +157,20 @@ class Config(object):
                 self._loaded_config_file = config_file
                 break
 
+        # Set the default values for section not configured
+        self.sections_set_default()
+
+    def sections_set_default(self):
+        # Globals
+        if not self.parser.has_section('global'):
+            self.parser.add_section('global')
+        self.set_default('global', 'strftime_format', '')
+
+        # check_update
+        if not self.parser.has_section('global'):
+            self.parser.add_section('global')
+        self.set_default('global', 'check_update', 'false')
+
         # Quicklook
         if not self.parser.has_section('quicklook'):
             self.parser.add_section('quicklook')
@@ -275,13 +293,13 @@ class Config(object):
         If it did not exist, then return the default value.
 
         It allows user to define dynamic configuration key (see issue#1204)
-        Dynamic vlaue should starts and end with the ` char
+        Dynamic value should starts and end with the ` char
         Example: prefix=`hostname`
         """
         ret = default
         try:
             ret = self.parser.get(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             pass
 
         # Search a substring `foo` and replace it by the result of its exec
@@ -298,19 +316,19 @@ class Config(object):
         """Get the int value of an option, if it exists."""
         try:
             return self.parser.getint(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return int(default)
 
     def get_float_value(self, section, option, default=0.0):
         """Get the float value of an option, if it exists."""
         try:
             return self.parser.getfloat(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return float(default)
 
     def get_bool_value(self, section, option, default=True):
         """Get the bool value of an option, if it exists."""
         try:
             return self.parser.getboolean(section, option)
-        except NoOptionError:
+        except (NoOptionError, NoSectionError):
             return bool(default)
