@@ -27,7 +27,7 @@ from glances import __version__, psutil_version
 from glances.compat import input
 from glances.config import Config
 from glances.globals import WINDOWS
-from glances.logger import logger
+from glances.logger import logger, LOG_FILENAME
 
 
 def disable(class_name, var):
@@ -80,10 +80,10 @@ Examples of use:
   Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):
     $ glances -t 5 --export influxdb
 
-  Start a Glances XML/RCP server (server mode):
+  Start a Glances XML-RPC server (server mode):
     $ glances -s
 
-  Connect Glances to a Glances XML/RCP server (client mode):
+  Connect Glances to a Glances XML-RPC server (client mode):
     $ glances -c <ip_server>
 
   Connect Glances to a Glances server and export stats to a StatsD server (client mode):
@@ -98,8 +98,11 @@ Examples of use:
   Display CSV stats to stdout (all stats in one line):
     $ glances --stdout-csv now,cpu.user,mem.used,load
 
-  Disable some plugins (any modes):
+  Disable some plugins (comma separated list):
     $ glances --disable-plugin network,ports
+
+  Enable some plugins (comma separated list):
+    $ glances --enable-plugin sensors
 """
 
     def __init__(self):
@@ -109,7 +112,7 @@ Examples of use:
 
     def init_args(self):
         """Init all the command line arguments."""
-        version = "Glances v" + __version__ + " with psutil v" + psutil_version
+        version = 'Glances v{} with PsUtil v{}\nLog file: {}'.format(__version__, psutil_version, LOG_FILENAME)
         parser = argparse.ArgumentParser(
             prog='glances',
             conflict_handler='resolve',
@@ -126,8 +129,10 @@ Examples of use:
                             action='store_true', default=False,
                             dest='modules_list',
                             help='display modules (plugins & exports) list and exit')
-        parser.add_argument('--disable-plugin', dest='disable_plugin',
+        parser.add_argument('--disable-plugin', '--disable-plugins', dest='disable_plugin',
                             help='disable plugin (comma separed list)')
+        parser.add_argument('--enable-plugin', '--enable-plugins', dest='enable_plugin',
+                            help='enable plugin (comma separed list)')
         parser.add_argument('--disable-process', action='store_true', default=False,
                             dest='disable_process', help='disable process module')
         # Enable or disable option
@@ -223,12 +228,16 @@ Examples of use:
                             dest='quiet', help='do not display the curses interface')
         parser.add_argument('-f', '--process-filter', default=None, type=str,
                             dest='process_filter', help='set the process filter pattern (regular expression)')
-        parser.add_argument('--process-short-name', action='store_true', default=False,
+        parser.add_argument('--process-short-name', action='store_true', default=True,
                             dest='process_short_name', help='force short name for processes name')
+        parser.add_argument('--process-long-name', action='store_false', default=False,
+                            dest='process_short_name', help='force long name for processes name')
         parser.add_argument('--stdout', default=None,
                             dest='stdout', help='display stats to stdout, one stat per line (comma separated list of plugins/plugins.attribute)')
         parser.add_argument('--stdout-csv', default=None,
                             dest='stdout_csv', help='display stats to stdout, csv format (comma separated list of plugins/plugins.attribute)')
+        parser.add_argument('--issue', default=None, action='store_true',
+                            dest='stdout_issue', help='test all plugins and exit (please copy/paste the output if you open an issue)')
         if not WINDOWS:
             parser.add_argument('--hide-kernel-threads', action='store_true', default=False,
                                 dest='no_kernel_threads', help='hide kernel threads in process list (not available on Windows)')
@@ -249,6 +258,9 @@ Examples of use:
         # Globals options
         parser.add_argument('--disable-check-update', action='store_true', default=False,
                             dest='disable_check_update', help='disable online Glances version ckeck')
+        parser.add_argument('--strftime', dest='strftime_format', default='',
+                            help='strftime format string for displaying current date in standalone mode')
+
         return parser
 
     def parse_args(self):
@@ -267,16 +279,19 @@ Examples of use:
             simplefilter("ignore")
 
         # Plugins disable/enable
+        # Allow users to disable plugins from the glances.conf (issue #1378)
+        for s in self.config.sections():
+            if self.config.has_section(s) \
+               and (self.config.get_bool_value(s, 'disable', False)):
+                disable(args, s)
+                logger.debug('{} disabled by the configuration file'.format(s))
+        # The configuration key can be overwrite from the command line
         if args.disable_plugin is not None:
             for p in args.disable_plugin.split(','):
                 disable(args, p)
-        else:
-            # Allow users to disable plugins from the glances.conf (issue #1378)
-            for s in self.config.sections():
-                if self.config.has_section(s) \
-                   and (self.config.get_bool_value(s, 'disable', False)):
-                    disable(args, s)
-                    logger.debug('{} disabled by the configuration file'.format(s))
+        if args.enable_plugin is not None:
+            for p in args.enable_plugin.split(','):
+                enable(args, p)
 
         # Exporters activation
         if args.export is not None:
@@ -297,13 +312,8 @@ Examples of use:
         if args.disable_autodiscover:
             logger.info("Auto discover mode is disabled")
 
-        # By default Windows is started in Web mode
-        if WINDOWS:
-            args.webserver = True
-
-        # In web server mode, default refresh time: 5 sec
+        # In web server mode
         if args.webserver:
-            args.time = 5
             args.process_short_name = True
 
         # Server or client login/password
@@ -416,6 +426,13 @@ Examples of use:
             disable(args, 'hddtemp')
             logger.debug("Sensors and HDDTemp are disabled")
 
+        # Let the plugins known the Glances mode
+        self.args.is_standalone = self.is_standalone()
+        self.args.is_client = self.is_client()
+        self.args.is_client_browser = self.is_client_browser()
+        self.args.is_server = self.is_server()
+        self.args.is_webserver = self.is_webserver()
+
         return args
 
     def is_standalone(self):
